[TOC]

# 10.5 脉冲编码调制（PCM）$\star$

> 调制：这里指将抽样、量化后的抽样信号加载到比特序列上

## 10.5.1 基本原理

- 编码：将离散值变成二进制码元的过程
- PCM：从模拟信号抽样、量化，直到变换成为二进制符号的基本过程
- 原理框图

  - 发送端

  $$
  模拟信号输入{\longrightarrow}\boxed{抽样保持}\longrightarrow\boxed{量化}\longrightarrow\boxed{编码}{\longrightarrow}PCM信号输出
  $$

  - 接收端

$$
PCM信号输入{\longrightarrow}\boxed{译码}\longrightarrow\boxed{低通滤波}{\longrightarrow}模拟信号输出
$$

模拟信号数字化过程：

![image-20231227183630474](https://mypic-1312707183.cos.ap-nanjing.myqcloud.com/image-20231227183630474.png)

## 10.5.2 常用二进制码

- 码字

在编码时，每个量化级都是用一定位数的二进制码来表示的，这一组二进制码就称为码字

- 码型

码字中码位的整体编排方式称为码型

- PCM中常用码型：
  - 自然码：一般的十进制正整数的二进制表示。
    - 特点：编码简单，译码可以逐比特独立进行。
  - 格雷码（循环二进制码）：相邻码字的距离恒为1.
  - **折叠码**（语音信号PCM编码用的多）：由极性码（最高位）和幅度码组成。幅度码从零电平到大电平按自然码规则编码。当正、负绝对值相同时，幅度码相对于零电平呈现镜像关系，或称折叠关系。
    - **优点** $\star$$\star$
      - 编码电路和编码过程简单(因为有正负极性的折叠关系，可以当成单极性的处理)
      - 误码对于小电压的影响较小，有利于减小语音信号的平均量化噪声

![image-20231227183810948](https://mypic-1312707183.cos.ap-nanjing.myqcloud.com/image-20231227183810948.png)

## 10.5.3 PCM编码规则

> 关乎通信质量和设备复杂度。

在A律13折线PCM编码中，共计$2 \times 8 \times 16=256=2^8$个量化级

![image-20231227183856957](https://mypic-1312707183.cos.ap-nanjing.myqcloud.com/image-20231227183856957.png)

- 极性码：表示样值的极性。正编“1”，负编“0”
- 段落码：表示样值的幅度所处的段落
- 段内码：16种可能状态对应代表各段内的16个量化级

### 段落码编码规则

| 段落序号 | 段落码$c_2c_3c_4$ | 段落范围(量化单位) |
| -------- | ----------------- | ------------------ |
| 8        | 111               | 1024~2024          |
| 7        | 110               | 512~1024           |
| 6        | 101               | 256~512            |
| 5        | 100               | 128~256            |
| 4        | 011               | 64~128             |
| 3        | 010               | 32~64              |
| 2        | 001               | 16~32              |
| 1        | 000               | 0~16               |

### 段内码编码规则

| 量化间隔 | 段内码$c_5c_6c_7c_8$ |
| -------- | -------------------- |
| 15       | 1111                 |
| 14       | 1110                 |
| 13       | 1101                 |
| 12       | 1100                 |
| 11       | 1011                 |
| 10       | 1010                 |
| 9        | 1001                 |
| 8        | 1000                 |
| 7        | 0111                 |
| 6        | 0110                 |
| 5        | 0101                 |
| 4        | 0100                 |
| 3        | 0011                 |
| 2        | 0010                 |
| 1        | 0001                 |
| 0        | 0000                 |

### 起始电平和量化间隔

确定样值（幅值）所在的段落和量化级

$\star$ $\star$ 归一化输入电压的最小量化单位：
$$
\Delta=\frac{1}{2048}
$$

| 段落序号 | 段落码$c_2c_3c_4$ | 段落范围($\Delta$) | 段落起始电平($\Delta$) | 段内量化间隔($\Delta_i$) |
| -------- | ----------------- | ------------------ | ---------------------- | ------------------------ |
| 8        | 111               | 1024~2024          | 1024                   | 64                       |
| 7        | 110               | 512~1024           | 512                    | 32                       |
| 6        | 101               | 256~512            | 256                    | 16                       |
| 5        | 100               | 128~256            | 128                    | 8                        |
| 4        | 011               | 64~128             | 64                     | 4                        |
| 3        | 010               | 32~64              | 32                     | 2                        |
| 2        | 001               | 16~32              | 16                     | 1                        |
| 1        | 000               | 0~16               | 0                      | 1                        |

### 编码步骤

$\Delta_i$为第$i$段的量化间隔。综上所述可得到A律13折线编码的步骤如下:

1. 对抽样值 $I$ 进行归一化, 归一化值为: $I_s=I / \Delta=I /\left(||_{\max } / 2048\right)$
2. 判断归一化值 $I_s$ 的符号, 确定 $C_1$;
3. 判断 $\left|I_s\right|$ 所处的段落, 确定段落码 $C_2 C_3 C_4$;
4. 确定段内码：段内偏移除以该段的量化间隔, 即 $\left(\left|I_s\right|-\right.\left.I_{B i}\right) / \Delta_i$ 取整数部分, 编码得到 $C_5 C_6 C_7 C_8, I_{B i}$ 为段落起始电 平, $\Delta_i$ 为量化间隔。
5.  $C_1 C_2 C_3 C_4 C_5 C_6 C_7 C_8$ 即为输出码字。

## 10.5.4 电话信号的编译码器

任务：把每个样值脉冲编出相应的 8 位二进码。

### PCM编码器原理

逐次比较型编码器原理框图

<img src="https://mypic-1312707183.cos.ap-nanjing.myqcloud.com/image-20221004082410505.png" alt="image-20221004082410505" style="zoom:50%;" />

各部件功能：

- 极性判决：确定样值信号的极性，编出极性码。样值为正取1，为负取0。
- 整流器：双$\Rightarrow$单（样值的幅度大小）。
- 保持电路：使每个样值的幅度在 7 次比较编码过程中保持不变。
- 比较器（核心）：将样值电流$I_s$与标准电流$I_w$进行逐次比较，使$I_s$向$I_w$逐步逼近，从而实现对信号抽样值的非均匀量化和编码。
- 若 $I_s＞I_w$，输出“1”码
- 若 $I_s<I_w$，输出“0”码
- 记忆电路：寄存前面编出的码，以便确定下一次的标准电流值$I_w$。
- 7/11变换：将 7 位非线性码转换成 11位线性码，以便恒流源产生所需的标准电流$I_w$。

### 逐次比较法译码原理

译码：把 PCM 信号  相应的 PAM 样值信号，即 D/A 变换。

<img src="https://mypic-1312707183.cos.ap-nanjing.myqcloud.com/image-20221004082858362.png" alt="image-20221004082858362" style="zoom:50%;" />

---

问：接收端译码器和编码器中的本地译码器有何不同？

答：增加了极性控制部分和带有寄存读出的7/12位码变换电路。

---

- 串/并变换记忆电路 ：将串行 PCM 码变为并行码,并记忆下来。
- 极性控制：根据收到的极性码 C1来控制译码后PAM信号的极性。
- 7/12变换电路（最关键）: 将7位非线性码转变为12位线性码。(编码器中7/11)
  - 目的：增加一个$\Delta V_i/2$恒流电流，人为地补上半个量化级，使最大量化误差不超过$\Delta V_i/2$ , 从而改善量化信噪比。
- 寄存读出电路：将输入的串行码在存储器中寄存起来,  待全部接收后再一起读出 , 送入解码网络。实质上是进行串/并变换。
- 12位线性解码电路 ：由恒流源和电阻网络组成,与编码器中解码网络类同。它是在寄存读出电路的控制下,输出相应的 PAM信号。 

<img src="https://mypic-1312707183.cos.ap-nanjing.myqcloud.com/image-20221004083232067.png" alt="image-20221004083232067" style="zoom: 50%;" />

## 10.5.5 PCM 信号的比特率和带宽

设模拟信号的最高频率为 $\boldsymbol{f}_{\mathrm{H}}$ ，抽样速率 $\boldsymbol{f}_{\mathrm{s}}=2 \boldsymbol{f}_{\mathrm{H}}$ ，二进制编码位数为 $N$, 则 PCM 信号的比特率为
$$
R_b=f_s \cdot N=2 f_H \cdot N
$$
最小带宽(没有码间串扰的最高码率)
$$
B_N=f_H \cdot N=R_b / 2=\frac{f_s \cdot N}{2}=\frac{R_B}{2}
$$
因此产生了问题：PCM信号占用的频带比标准话路带宽要宽很多倍。

---

## 10.5.6 PCM系统中噪声的影响

- 两种噪声

$$
\hat{m}(t)=m(t)+n_q(t)+n_a(t)
$$

等式右边三项分别是信号成分($S_0$)、量化噪声($N_q$)、加性噪声($N_a$)。

两种噪声产生就机理不同，因而相互独立。

- 性能指标

$\star$**抗加性噪声性能**
$$
\frac{S_{\mathrm{o}}}{N_{\mathrm{a}}}=\frac{E\left[m^2(t)\right]}{E\left[n_{\mathrm{a}}^2(t)\right]}=\frac{M^2}{2^{2(N+1)} P_e}=\frac{1}{4 P_e}
$$

**对于一个频带限制在$f_H$的低通信号，按照抽样定理，要求抽样速率不低于$2f_H 次/s$。
对于PCM系统，这相当于要求传输速率至少为$2Nf_H bit/s$**

$\star$**抗量化噪声性能**
$$
\frac{S_{\mathrm{o}}}{N_q}=\frac{E\left[m^2(t)\right]}{E\left[n_q^2(t)\right]}=M^2=2^{2 N}=2^{2 B / f_{\mathrm{H}}}
$$

**含义：当低通信号最高频率 fH 给定时, PCM系统的输出信号量噪比随系统的带宽 B 按指数规律增长。——带宽与信噪比互换**

总输出信噪比
$$
\frac{S_{\mathrm{o}}}{N_{\mathrm{o}}}=\frac{E\left[m^2(t)\right]}{E\left[n_q^2(t)\right]+E\left[n_{\mathrm{a}}^2(t)\right]}=\frac{S_{\mathrm{o}} / N_q}{1+N_{\mathrm{a}} / N_q}=\frac{2^{2 N}}{1+4 P_e 2^{2 N}}
$$
若 $N_{\mathrm{a}}<<N_q$，则
$$
\frac{S_{\mathrm{o}}}{N_{\mathrm{o}}} \approx 2^{2 N}
$$
若 $N_{\mathrm{a}}>>N_q$，则
$$
\frac{S_0}{N_a} \approx \frac{1}{4 P_e}
$$
**假设条件：自然码、均匀量化、输入信号为均匀分布。**

